@@ -1,6 +1,6 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300015'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300017'; # TRIAL
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -9,6 +9,8 @@ use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
 use MooX::Types::MooseLike::Base qw(Bool Int Str);
 
+use utf8 (); # See below. -- rjbs, 2015-05-14
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This transport is used to send email over SMTP, either with or without secure
@@ -34,6 +36,12 @@ use MooX::Types::MooseLike::Base qw(Bool Int Str);
 #pod
 #pod =cut
 
+sub BUILD {
+  my ($self) = @_;
+  Carp::croak("do not pass port number to SMTP transport in host, use port parameter")
+    if $self->host =~ /:/;
+}
+
 has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
 has ssl  => (is => 'ro', isa => Bool, default => sub { 0 });
 has port => (
@@ -203,6 +211,12 @@ sub send_email {
 
   while (length $msg_string) {
     my $next_hunk = substr $msg_string, 0, $hunk_size, '';
+
+    # I would love to remove this when Net::SMTP is unscrewed.
+    # See https://rt.cpan.org/Ticket/Display.html?id=104433
+    # -- rjbs, 2015-05-14
+    utf8::downgrade($next_hunk);
+
     $smtp->datasend($next_hunk) or $FAULT->("error at during DATA");
   }
 
@@ -261,7 +275,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300015
+version 1.300017
 
 =head1 DESCRIPTION
 
@@ -314,7 +328,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
